@@ -48,12 +48,13 @@ class BaseParser(object):
     def init(self, validation):
         self.validation = validation
 
-    def err(self, errmsg):
+    def err(self, msg, context=None, token=None):
         "Report a parse error and abort."
-        token = None
-        if self.has_tokens():
+        if token is None and self.has_tokens():
             token = self._cmd[self._currtok]
-        syntax_err(self._cmd, context=self._cmd[0], token=token, msg=errmsg)
+        if context is None:
+            context = self._cmd[0]
+        syntax_err(self._cmd, context=context, token=token, msg=msg)
         raise ParseError
 
     def begin(self, cmd, min_args=-1):
@@ -190,7 +191,7 @@ class BaseParser(object):
         """
         ret = []
         if terminator is None:
-            terminator = RuleParser._TERMINATORS
+            terminator = RuleParser.TERMINATORS
         while True:
             tok = self.current_token()
             if tok is not None and tok.lower() in terminator:
@@ -314,7 +315,7 @@ class RuleParser(BaseParser):
     _UNARYOP_RE = re.compile(r'(%s)$' % ('|'.join(constants.unary_ops)), re.IGNORECASE)
     _BINOP_RE = None
 
-    _TERMINATORS = ('params', 'meta', 'utilization', 'operations', 'op', 'rule', 'attributes')
+    TERMINATORS = ('params', 'meta', 'utilization', 'operations', 'op', 'rule', 'attributes')
 
     def match_attr_list(self, name, tag, allow_empty=True):
         """
@@ -581,7 +582,6 @@ class NodeParser(RuleParser):
 class ResourceParser(RuleParser):
     _TEMPLATE_RE = re.compile(r'@(.+)$')
     _RA_TYPE_RE = re.compile(r'[a-z0-9_:-]+$', re.IGNORECASE)
-    _OPTYPE_RE = re.compile(r'(%s)$' % ('|'.join(constants.op_cli_names)), re.IGNORECASE)
 
     def can_parse(self):
         return ('primitive', 'group', 'clone', 'ms', 'master', 'rsc_template')
@@ -610,7 +610,7 @@ class ResourceParser(RuleParser):
           </op>
         """
         self.match('op')
-        op_type = self.match(self._OPTYPE_RE, errmsg="Expected operation type")
+        op_type = self.match_identifier()
         all_attrs = self.match_nvpairs(minpairs=0)
         node = xmlbuilder.new('op', name=op_type)
         if not any(nvp.get('name') == 'interval' for nvp in all_attrs):
@@ -879,11 +879,11 @@ class ConstraintParser(RuleParser):
         return [[name, info[0]]]
 
     def _split_setref(self, typename, classifier):
-            rsc, typ = self.match_split()
-            typ, t = classifier(typ)
-            if typ and not t:
-                self.err("Invalid %s '%s' for '%s'" % (typename, typ, rsc))
-            return rsc, typ, t
+        rsc, typ = self.match_split()
+        typ, t = classifier(typ)
+        if typ and not t:
+            self.err("Invalid %s '%s' for '%s'" % (typename, typ, rsc))
+        return rsc, typ, t
 
     def match_simple_role_set(self, count):
         ret = self._fmt(self._split_setref('role', self.validation.classify_role), 'rsc')
@@ -976,7 +976,7 @@ class FencingOrderParser(BaseParser):
     """
 
     _TARGET_RE = re.compile(r'([\w=-]+):$')
-    _TARGET_ATTR_RE = re.compile(r'attr:([\w-]+)=([\w-]+)$')
+    _TARGET_ATTR_RE = re.compile(r'attr:([\w-]+)=([\w-]+)$', re.IGNORECASE)
 
     def can_parse(self):
         return ('fencing-topology', 'fencing_topology')
@@ -1319,9 +1319,9 @@ class ResourceSet(object):
         '(': ')',
     }
 
-    def __init__(self, type, s, parent):
+    def __init__(self, q_attr, s, parent):
         self.parent = parent
-        self.q_attr = type
+        self.q_attr = q_attr
         self.tokens = s
         self.cli_list = []
         self.reset_set()
@@ -1398,11 +1398,7 @@ class ResourceSet(object):
         return l
 
     def err(self, errmsg, token=''):
-        syntax_err(self.parent._cmd,
-                   context=self.q_attr,
-                   token=token,
-                   msg=errmsg)
-        raise ParseError
+        self.parent.err(msg=errmsg, context=self.q_attr, token=token)
 
     def update_attrs(self, bracket, tokpos):
         if bracket in ('(', '['):
