@@ -72,27 +72,27 @@ class Text(object):
 
     @staticmethod
     def shortdesc(script, text):
-        return Text(script, text, type=Text.SHORTDESC)
+        return Text(script, text, kind=Text.SHORTDESC)
 
     @staticmethod
     def desc(script, text):
-        return Text(script, text, type=Text.DESC)
+        return Text(script, text, kind=Text.DESC)
 
     @staticmethod
     def cib(script, text):
-        return Text(script, text, type=Text.CIB)
+        return Text(script, text, kind=Text.CIB)
 
     @staticmethod
     def isa(obj):
         return isinstance(obj, basestring) or isinstance(obj, Text)
 
-    def __init__(self, script, text, type=None):
+    def __init__(self, script, text, kind=None):
         self.script = script
         if isinstance(text, Text):
             self.text = text.text
         else:
             self.text = text
-        self.type = type
+        self._kind = kind
 
     def _parse(self):
         val = self.text
@@ -106,11 +106,11 @@ class Text(object):
         return repr(self.text)
 
     def __str__(self):
-        if self.type == self.DESC:
+        if self._kind == self.DESC:
             return format_desc(self._parse())
-        elif self.type == self.SHORTDESC:
+        elif self._kind == self.SHORTDESC:
             return self._parse()
-        elif self.type == self.CIB:
+        elif self._kind == self.CIB:
             return format_cib(self._parse())
         return self._parse()
 
@@ -153,7 +153,7 @@ class Actions(object):
     Each method in this class handles a particular action.
     """
     @staticmethod
-    def _parse(script, action):
+    def parse(script, action):
         """
         action: action data (dict)
         params: flat list of parameter values
@@ -183,7 +183,7 @@ class Actions(object):
                 action['value'] = value
 
             def arrow(v):
-                return ' -> '.join(x.items()[0])
+                return ' -> '.join(v.items()[0])
             action['text'] = '\n'.join([arrow(x) for x in value])
         elif name == 'cib' or name == 'crm':
             action['text'] = str(Text.cib(script, value))
@@ -204,21 +204,29 @@ class Actions(object):
             action['longdesc'] = ''
         else:
             action['longdesc'] = Text.desc(script, action['longdesc'])
+
+        hre = handles.headmatcher
+
         if 'when' in action:
             when = action['when']
-            if re.search(r'\{\{.*\}\}', when):
+            if hre.search(when):
                 action['when'] = Text(script, when)
             elif when:
                 action['when'] = Text(script, '{{%s}}' % (when))
             else:
                 del action['when']
+        for k, v in action.iteritems():
+            if isinstance(v, basestring) and hre.search(v):
+                v = Text(script, v)
+            if Text.isa(v):
+                action[k] = str(v).strip()
 
     @staticmethod
-    def _mergeable(action):
+    def mergeable(action):
         return action['name'] in ('cib', 'crm', 'install', 'service')
 
     @staticmethod
-    def _merge(into, new):
+    def merge(into, new):
         """
         Merge neighbour actions.
         Note: When this is called, all text values
@@ -247,9 +255,9 @@ class Actions(object):
         return True
 
     @staticmethod
-    def _needs_sudo(action):
-        if action['name'] == 'call' and action.get('sudo'):
-            return True
+    def needs_sudo(action):
+        if action['name'] == 'call':
+            return action.get('sudo') or action.get('nodes') != 'local'
         return action['name'] in ('apply', 'apply_local', 'install', 'service')
 
     def __init__(self, run, action):
@@ -463,11 +471,11 @@ def _upgrade_yaml(data):
 _hawk_template_cache = {}
 
 
-def _parse_hawk_template(workflow, name, type, step, actions):
+def _parse_hawk_template(workflow, name, kind, step, actions):
     """
     Convert a hawk template into steps + a cib action
     """
-    path = os.path.join(os.path.dirname(workflow), '../templates', type + '.xml')
+    path = os.path.join(os.path.dirname(workflow), '../templates', kind + '.xml')
     if path in _hawk_template_cache:
         xml = _hawk_template_cache[path]
     elif os.path.isfile(path):
@@ -598,7 +606,7 @@ def _parse_hawk_workflow(scriptname, scriptfile):
     return data
 
 
-def _build_script_cache():
+def build_script_cache():
     global _script_cache
     if _script_cache is not None:
         return
@@ -624,7 +632,7 @@ def list_scripts():
     List the available cluster installation scripts.
     Yields the names of the main script files.
     '''
-    _build_script_cache()
+    build_script_cache()
     return sorted(_script_cache.keys())
 
 
@@ -691,8 +699,7 @@ def _process_agent_include(script, include):
         raise ValueError("No meta-data for agent: %s" % (agent))
     name = include.get('name', meta.get('name'))
     if not name:
-        cls, provider, type = ra.disambiguate_ra_type(agent)
-        name = type
+        cls, provider, name = ra.disambiguate_ra_type(agent)
     if 'name' not in include:
         include['name'] = name
     step = _listfindpend(name, script['steps'], lambda x: x.get('name'), lambda: {
@@ -989,7 +996,7 @@ def _join_script_lines(txt):
     return s
 
 
-def _load_script_file(script, filename):
+def load_script_file(script, filename):
     if filename.endswith('.yml'):
         parsed = _parse_yaml(script, filename)
     elif filename.endswith('.xml'):
@@ -1005,7 +1012,7 @@ def _load_script_file(script, filename):
 
 
 def load_script_string(script, yml):
-    _build_script_cache()
+    build_script_cache()
     import cStringIO
     import yaml
     data = yaml.load(cStringIO.StringIO(yml))
@@ -1027,14 +1034,14 @@ def load_script_string(script, yml):
 
 
 def load_script(script):
-    _build_script_cache()
+    build_script_cache()
     if script not in _script_cache:
         common_debug("cache: %s" % (_script_cache.keys()))
         raise ValueError("Script not found: %s" % (script))
     s = _script_cache[script]
     if isinstance(s, basestring):
         try:
-            return _load_script_file(script, s)
+            return load_script_file(script, s)
         except KeyError as err:
             raise ValueError("Error when loading script %s: Expected key %s not found" % (script, err))
         except Exception as err:
@@ -1110,13 +1117,14 @@ def _generate_workdir_name():
 def _print_debug(printer, local_node, hosts, workdir, opts):
     "Print debug output (if any)"
     dbglog = os.path.join(workdir, 'crm_script.debug')
-    for host, result in _parallax_call(printer, hosts,
-                                       "if [ -f '%s' ]; then cat '%s'; fi" % (dbglog, dbglog),
-                                       opts).iteritems():
-        if isinstance(result, parallax.Error):
-            printer.error(host, result)
-        else:
-            printer.output(host, *result)
+    if hosts:
+        for host, result in _parallax_call(printer, hosts,
+                                           "if [ -f '%s' ]; then cat '%s'; fi" % (dbglog, dbglog),
+                                           opts).iteritems():
+            if isinstance(result, parallax.Error):
+                printer.error(host, result)
+            else:
+                printer.output(host, *result)
     if os.path.isfile(dbglog):
         f = open(dbglog).read()
         printer.output(local_node, 0, f, '')
@@ -1279,24 +1287,24 @@ def _valid_ip(value):
 def _verify_type(param, value, errors):
     if value is None:
         value = ''
-    type = param.get('type')
-    if not type:
+    vtype = param.get('type')
+    if not vtype:
         return value
-    elif type == 'integer':
+    elif vtype == 'integer':
         ok, _ = _valid_integer(value)
         if not ok:
             errors.append("%s=%s is not an integer" % (param.get('name'), value))
-    elif type == 'string':
+    elif vtype == 'string':
         return value
-    elif type == 'boolean':
+    elif vtype == 'boolean':
         return "true" if _make_boolean(value) else "false"
-    elif type == 'resource':
+    elif vtype == 'resource':
         try:
             if not _IDENT_RE.match(value):
                 errors.append("%s=%s invalid resource identifier" % (param.get('name'), value))
         except TypeError as e:
             errors.append("%s=%s %s" % (param.get('name'), value, str(e)))
-    elif type == 'enum':
+    elif vtype == 'enum':
         if 'values' not in param:
             errors.append("%s=%s enum without list of values" % (param.get('name'), value))
         else:
@@ -1306,12 +1314,11 @@ def _verify_type(param, value, errors):
             for v in opts:
                 if value.lower() == v.lower():
                     return v
-            else:
-                errors.append("%s=%s does not match '%s'" % (param.get('name'), value, "|".join(opts)))
-    elif type == 'ip_address':
+            errors.append("%s=%s does not match '%s'" % (param.get('name'), value, "|".join(opts)))
+    elif vtype == 'ip_address':
         if not _valid_ip(value):
             errors.append("%s=%s is not an IP address" % (param.get('name'), value))
-    elif type == 'ip_network':
+    elif vtype == 'ip_network':
         sp = value.rsplit('/', 1)
         if len(sp) == 1 and not (is_valid_ipv4_address(value) or is_valid_ipv6_address(value)):
             errors.append("%s=%s is not a valid IP network" % (param.get('name'), value))
@@ -1319,17 +1326,17 @@ def _verify_type(param, value, errors):
             errors.append("%s=%s is not a valid IP network" % (param.get('name'), value))
         else:
             errors.append("%s=%s is not a valid IP network" % (param.get('name'), value))
-    elif type == 'port':
+    elif vtype == 'port':
         ok, ival = _valid_integer(value)
         if not ok:
             errors.append("%s=%s is not a valid port" % (param.get('name'), value))
         if ival < 0 or ival > 65535:
             errors.append("%s=%s is out of port range" % (param.get('name'), value))
-    elif type == 'email':
+    elif vtype == 'email':
         if not re.match(r'[^@]+@[^@]+', value):
             errors.append("%s=%s is not a valid email address" % (param.get('name'), value))
     else:
-        errors.append("%s=%s is unknown type %s" % (param.get('name'), value, type))
+        errors.append("%s=%s is unknown type %s" % (param.get('name'), value, vtype))
     return value
 
 _NO_RESOLVE = object()
@@ -1762,7 +1769,7 @@ class RunActions(object):
             if not os.path.isfile(statefile):
                 raise ValueError("No state for action: %s" % (action_index))
             self.data = json.load(open(statefile))
-        if Actions._needs_sudo(action):
+        if Actions.needs_sudo(action):
             self._check_sudo_pass()
         result = self._run_action(action)
         json.dump(self.data, open(self.statefile, 'w'))
@@ -1774,7 +1781,7 @@ class RunActions(object):
         # run on local nodes
         # TODO: wait for remote results
         for action in self.actions:
-            if Actions._needs_sudo(action):
+            if Actions.needs_sudo(action):
                 self._check_sudo_pass()
             if not self._run_action(action):
                 return False
@@ -1870,7 +1877,7 @@ class RunActions(object):
         return False
 
     def _check_sudo_pass(self):
-        if self.sudo and not self.sudo_pass:
+        if self.sudo and not self.sudo_pass and userdir.getuser() != 'root':
             prompt = "sudo password: "
             self.sudo_pass = getpass.getpass(prompt=prompt)
 
@@ -1878,6 +1885,8 @@ class RunActions(object):
         islocal = False
         if nodes == 'all':
             pass
+        elif nodes == 'local':
+            islocal = True
         elif nodes is not None and nodes != []:
             islocal = nodes == [self.local_node_name()]
         else:
@@ -1886,16 +1895,20 @@ class RunActions(object):
         return islocal
 
     def call(self, nodes, cmdline, is_json_output=False):
-        if not self._is_local(nodes):
-            self.result = self._process_remote(cmdline, is_json_output)
+        if cmdline.startswith("#!"):
+            self.execute_shell(nodes or 'all', cmdline)
         else:
-            self.result = self._process_local(cmdline, is_json_output)
-        self.rc = self.result not in (False, None)
+            if not self._is_local(nodes):
+                self.result = self._process_remote(cmdline, is_json_output)
+            else:
+                self.result = self._process_local(cmdline, is_json_output)
+            self.rc = self.result not in (False, None)
 
     def execute_shell(self, nodes, cmdscript):
         """
         execute the shell script...
         """
+        cmdscript = str(cmdscript).rstrip() + '\n'
         if self.dry_run:
             self.printer.print_command(nodes, cmdscript)
             self.result = ''
@@ -2008,7 +2021,8 @@ class RunActions(object):
             return None
         self.printer.debug("Result(local): %s" % repr(out))
         if is_json_output:
-            out = json.loads(out)
+            if out != '':
+                out = json.loads(out)
         return out
 
     def local_node_name(self):
@@ -2069,8 +2083,10 @@ def run(script, params, printer):
         if not dry_run:
             if not config.core.debug:
                 _run_cleanup(printer, has_remote_actions, local_node, hosts, workdir, opts)
-            else:
+            elif has_remote_actions:
                 _print_debug(printer, local_node, hosts, workdir, opts)
+            else:
+                _print_debug(printer, local_node, None, workdir, opts)
 
 
 def _remove_empty_lines(txt):
@@ -2114,7 +2130,7 @@ def _process_actions(script, params):
             if action['include'] in subactions:
                 toadd.extend(subactions[action['include']])
         else:
-            Actions._parse(script, action)
+            Actions.parse(script, action)
             if 'when' in action:
                 when = str(action['when']).strip()
                 if when not in (False, None, '', 'false'):
@@ -2123,8 +2139,8 @@ def _process_actions(script, params):
                 toadd.append(action)
         if ret:
             for add in toadd:
-                if Actions._mergeable(add) and ret[-1]['name'] == add['name']:
-                    if not Actions._merge(ret[-1], add):
+                if Actions.mergeable(add) and ret[-1]['name'] == add['name']:
+                    if not Actions.merge(ret[-1], add):
                         ret.append(add)
                 else:
                     ret.append(add)
