@@ -87,7 +87,7 @@ def stonith_resource_list(args):
 
 def _load_2nd_completer(args):
     if args[1] == 'xml':
-        return ['replace', 'update']
+        return ['replace', 'update', 'push']
     return []
 
 
@@ -324,12 +324,7 @@ class CibConfig(command.UI):
             else:
                 print v
         for p in properties:
-            v = cib_factory.get_property(p)
-            if v is None:
-                try:
-                    v = ra.get_properties_meta().param_default(p)
-                except:
-                    pass
+            v = cib_factory.get_property_w_default(p)
             if v is not None:
                 print_value(v)
             elif truth:
@@ -491,9 +486,9 @@ class CibConfig(command.UI):
         return set_obj.save_to_file(filename)
 
     @command.skill_level('administrator')
-    @command.completers(compl.choice(['xml', 'replace', 'update']), _load_2nd_completer)
+    @command.completers(compl.choice(['xml', 'replace', 'update', 'push']), _load_2nd_completer)
     def do_load(self, context, *args):
-        "usage: load [xml] {replace|update} {<url>|<path>}"
+        "usage: load [xml] {replace|update|push} {<url>|<path>}"
         if len(args) < 2:
             context.fatal_error("Expected 2 arguments (0 given)")
         if args[0] == "xml":
@@ -508,7 +503,7 @@ class CibConfig(command.UI):
             url = args[1]
             method = args[0]
             xml = False
-        if method not in ("replace", "update"):
+        if method not in ("replace", "update", "push"):
             context.fatal_error("Unknown method %s" % method)
         if method == "replace":
             if options.interactive and cib_factory.has_cib_changed():
@@ -552,6 +547,7 @@ class CibConfig(command.UI):
             if not ok or not cib_factory.commit():
                 raise ValueError("Failed to stop one or more running resources: %s" %
                                  (', '.join(to_stop)))
+        return len(to_stop)
 
     @command.skill_level('administrator')
     @command.completers_repeating(_id_list)
@@ -562,8 +558,8 @@ class CibConfig(command.UI):
         arg_force = any((x in ('-f', '--force')) for x in argl)
         argl = [x for x in argl if (x not in ('-f', '--force'))]
         if arg_force or config.core.force:
-            self._stop_if_running(argl)
-            utils.wait4dc(what="Stopping %s" % (", ".join(argl)))
+            if self._stop_if_running(argl) > 0:
+                utils.wait4dc(what="Stopping %s" % (", ".join(argl)))
         return cib_factory.delete(*argl)
 
     @command.name('default-timeouts')
@@ -610,9 +606,6 @@ class CibConfig(command.UI):
         return ui_utils.ptestlike(set_obj.ptest, 'vv', context.get_command_name(), args)
 
     def _commit(self, force=False, replace=False):
-        if force:
-            syntax_err(('configure.commit', force))
-            return False
         if not cib_factory.has_cib_changed():
             common_info("apparently there is nothing to commit")
             common_info("try changing something first")
