@@ -109,8 +109,8 @@ class JsonPrinter(object):
         pass
 
 
-def describe_param(p, name, all):
-    if not all and p.get('advanced'):
+def describe_param(p, name, getall):
+    if not getall and p.get('advanced'):
         return ""
     opt = ' (required) ' if p['required'] else ''
     opt += ' (unique) ' if p['unique'] else ''
@@ -127,7 +127,7 @@ def _scoped_name(context, name):
     return name
 
 
-def describe_step(icontext, context, s, all):
+def describe_step(icontext, context, s, getall):
     ret = "%s. %s" % ('.'.join([str(i + 1) for i in icontext]), scripts.format_desc(s['shortdesc']) or 'Parameters')
     if not s['required']:
         ret += ' (optional)'
@@ -135,9 +135,9 @@ def describe_step(icontext, context, s, all):
     if s.get('name'):
         context = context + [s['name']]
     for p in s.get('parameters', []):
-        ret += describe_param(p, _scoped_name(context, p['name']), all)
+        ret += describe_param(p, _scoped_name(context, p['name']), getall)
     for i, step in enumerate(s.get('steps', [])):
-        ret += describe_step(icontext + [i], context, step, all)
+        ret += describe_step(icontext + [i], context, step, getall)
     return ret
 
 
@@ -159,12 +159,17 @@ def _nvpairs2parameters(args):
         _set(ret, key.split(':'), val)
     return ret
 
+_fixups = {
+    'wizard': 'Legacy Wizards',
+    'sap': 'SAP',
+    'nfs': 'NFS'
+}
+
 
 def _category_pretty(c):
-    if str(c).lower() == 'wizard':
-        return "Wizard (Legacy)"
-    elif str(c).lower() == 'sap':
-        return "SAP"
+    v = _fixups.get(str(c).lower())
+    if v is not None:
+        return v
     return str(c).capitalize()
 
 
@@ -189,7 +194,7 @@ class Script(command.UI):
         for arg in args:
             if arg.lower() not in ("all", "names"):
                 context.fatal_error("Unexpected argument '%s': expected  [all|names]" % (arg))
-        all = any([x for x in args if x.lower() == 'all'])
+        show_all = any([x for x in args if x.lower() == 'all'])
         names = any([x for x in args if x.lower() == 'names'])
         if not names:
             categories = {}
@@ -199,7 +204,7 @@ class Script(command.UI):
                     if script is None:
                         continue
                     cat = script['category'].lower()
-                    if not all and cat == 'script':
+                    if not show_all and cat == 'script':
                         continue
                     cat = _category_pretty(cat)
                     if cat not in categories:
@@ -214,7 +219,7 @@ class Script(command.UI):
                 for s in sorted(lst):
                     print(s)
                 print('')
-        elif all:
+        elif show_all:
             for name in scripts.list_scripts():
                 print(name)
         else:
@@ -230,7 +235,7 @@ class Script(command.UI):
 
     @command.completers_repeating(compl.call(scripts.list_scripts))
     @command.alias('info', 'describe')
-    def do_show(self, context, name, all=None):
+    def do_show(self, context, name, show_all=None):
         '''
         Describe the given script.
         '''
@@ -238,14 +243,14 @@ class Script(command.UI):
         if script is None:
             return False
 
-        all = all == 'all'
+        show_all = show_all == 'all'
 
         vals = {
             'name': script['name'],
             'category': _category_pretty(script['category']),
             'shortdesc': str(script['shortdesc']),
             'longdesc': scripts.format_desc(script['longdesc']),
-            'steps': "\n".join((describe_step([i], [], s, all) for i, s in enumerate(script['steps'])))}
+            'steps': "\n".join((describe_step([i], [], s, show_all) for i, s in enumerate(script['steps'])))}
         output = """%(name)s (%(category)s)
 %(shortdesc)s
 
@@ -253,7 +258,7 @@ class Script(command.UI):
 
 %(steps)s
 """ % vals
-        if all:
+        if show_all:
             output += "Common Parameters\n\n"
             for name, defval, desc in scripts.common_params():
                 output += "  %s\n" % (name)
@@ -370,9 +375,9 @@ class Script(command.UI):
         fromscript = os.path.abspath(workflow)
         tgtdir = outdir
 
-        scripts._build_script_cache()
+        scripts.build_script_cache()
         name = os.path.splitext(os.path.basename(fromscript))[0]
-        script = scripts._load_script_file(name, fromscript)
+        script = scripts.load_script_file(name, fromscript)
         script = flatten(script)
         script["category"] = category
         del script["name"]
@@ -445,11 +450,14 @@ class Script(command.UI):
             return False
         else:
             for action in actions:
-                print(json.dumps({'name': str(action.get('name', '')),
-                                  'shortdesc': str(action.get('shortdesc', '')),
-                                  'longdesc': str(action.get('longdesc', '')),
-                                  'text': str(action.get('text', '')),
-                                  'nodes': str(action.get('nodes', ''))}))
+                obj = {'name': str(action.get('name', '')),
+                       'shortdesc': str(action.get('shortdesc', '')),
+                       'longdesc': str(action.get('longdesc', '')),
+                       'text': str(action.get('text', '')),
+                       'nodes': str(action.get('nodes', ''))}
+                if 'sudo' in action:
+                    obj['sudo'] = action['sudo']
+                print(json.dumps(obj))
         return True
 
     def _json_run(self, context, cmd):
