@@ -11,6 +11,9 @@ import time
 import datetime
 import shutil
 import bz2
+import fnmatch
+import gc
+from contextlib import contextmanager
 from . import config
 from . import userdir
 from . import constants
@@ -19,18 +22,25 @@ from . import term
 from .msg import common_warn, common_info, common_debug, common_err, err_buf
 
 
-class memoize:
+def memoize(function):
     "Decorator to invoke a function once only for any argument"
-    def __init__(self, function):
-        self.function = function
-        self.memoized = {}
+    memoized = {}
+    def inner(*args):
+        if args in memoized:
+            return memoized[args]
+        r = function(*args)
+        memoized[args] = r
+        return r
+    return inner
 
-    def __call__(self, *args):
-        try:
-            return self.memoized[args]
-        except KeyError:
-            self.memoized[args] = self.function(*args)
-            return self.memoized[args]
+
+@contextmanager
+def nogc():
+    gc.disable()
+    try:
+        yield
+    finally:
+        gc.enable()
 
 
 getuser = userdir.getuser
@@ -158,10 +168,18 @@ def verify_boolean(opt):
 
 
 def is_boolean_true(opt):
+    if opt in (None, False):
+        return False
+    if opt is True:
+        return True
     return opt.lower() in ("yes", "true", "on", "1")
 
 
 def is_boolean_false(opt):
+    if opt in (None, False):
+        return True
+    if opt is True:
+        return False
     return opt.lower() in ("no", "false", "off", "0")
 
 
@@ -238,7 +256,7 @@ def pipe_string(cmd, s):
         p.communicate(s)
         p.wait()
         rc = p.returncode
-    except IOError, msg:
+    except IOError as msg:
         if "Broken pipe" not in msg:
             common_err(msg)
     return rc
@@ -443,31 +461,31 @@ _LOCKDIR = ".lockdir"
 _PIDF = "pid"
 
 
-def check_locker(dir):
-    if not os.path.isdir(os.path.join(dir, _LOCKDIR)):
+def check_locker(lockdir):
+    if not os.path.isdir(os.path.join(lockdir, _LOCKDIR)):
         return
-    s = file2str(os.path.join(dir, _LOCKDIR, _PIDF))
+    s = file2str(os.path.join(lockdir, _LOCKDIR, _PIDF))
     pid = convert2ints(s)
     if not isinstance(pid, int):
         common_warn("history: removing malformed lock")
-        rmdir_r(os.path.join(dir, _LOCKDIR))
+        rmdir_r(os.path.join(lockdir, _LOCKDIR))
         return
     try:
         os.kill(pid, 0)
     except OSError, (errno, strerror):
         if errno == os.errno.ESRCH:
             common_info("history: removing stale lock")
-            rmdir_r(os.path.join(dir, _LOCKDIR))
+            rmdir_r(os.path.join(lockdir, _LOCKDIR))
         else:
             common_err("%s: %s" % (_LOCKDIR, strerror))
 
 
-def acquire_lock(dir):
-    check_locker(dir)
+def acquire_lock(lockdir):
+    check_locker(lockdir)
     while True:
         try:
-            os.makedirs(os.path.join(dir, _LOCKDIR))
-            str2file("%d" % os.getpid(), os.path.join(dir, _LOCKDIR, _PIDF))
+            os.makedirs(os.path.join(lockdir, _LOCKDIR))
+            str2file("%d" % os.getpid(), os.path.join(lockdir, _LOCKDIR, _PIDF))
             return True
         except OSError, (errno, strerror):
             if errno != os.errno.EEXIST:
@@ -479,8 +497,8 @@ def acquire_lock(dir):
             return False
 
 
-def release_lock(dir):
-    rmdir_r(os.path.join(dir, _LOCKDIR))
+def release_lock(lockdir):
+    rmdir_r(os.path.join(lockdir, _LOCKDIR))
 
 
 def pipe_cmd_nosudo(cmd):
@@ -682,15 +700,15 @@ def run_ptest(graph_s, nograph, scores, utilization, actions, verbosity):
     return True
 
 
-def is_id_valid(id):
+def is_id_valid(ident):
     """
     Verify that the id follows the definition:
     http://www.w3.org/TR/1999/REC-xml-names-19990114/#ns-qualnames
     """
-    if not id:
+    if not ident:
         return False
     id_re = r"^[A-Za-z_][\w._-]*$"
-    return re.match(id_re, id)
+    return re.match(id_re, ident)
 
 
 def check_range(a):
@@ -764,29 +782,13 @@ def sort_by_mtime(l):
     return [x[1] for x in l2]
 
 
-def dirwalk(dir):
-    "walk a directory tree, using a generator"
-    # http://code.activestate.com/recipes/105873/
-    for f in os.listdir(dir):
-        fullpath = os.path.join(dir, f)
-        if os.path.isdir(fullpath) and not os.path.islink(fullpath):
-            for x in dirwalk(fullpath):  # recurse into subdir
-                yield x
-        else:
-            yield fullpath
-
-
-def file_find_by_name(dir, fname):
-    'Find a file within a tree matching fname.'
-    if not dir:
-        common_err("cannot dirwalk nothing!")
-        return None
-    if not fname:
-        common_err("file to find not provided")
-        return None
-    for f in dirwalk(dir):
-        if os.path.basename(f) == fname:
-            return f
+def file_find_by_name(root, filename):
+    'Find a file within a tree matching fname'
+    assert(root)
+    assert(filename)
+    for root, dirnames, filenames in os.walk(root):
+        for filename in fnmatch.filter(filenames, filename):
+            return os.path.join(root, filename)
     return None
 
 
@@ -924,6 +926,15 @@ def page_string(s):
         pipe_string(get_pager_cmd(), term_render(s))
 
 
+def page_gen(g):
+    'Page lines generated by generator g'
+    w, h = get_winsize()
+    if not config.core.pager or not can_ask() or options.batch:
+        for line in g:
+            sys.stdout.write(term_render(line))
+    else:
+        pipe_string(get_pager_cmd(), term_render("".join(g)))
+
 def page_file(filename):
     'Open file in pager'
     if not os.path.isfile(filename):
@@ -1059,6 +1070,15 @@ def datetime_to_timestamp(dt):
         return None
 
 
+def timestamp_to_datetime(ts):
+    """
+    Convert a timestamp into a naive datetime object
+    """
+    import dateutil
+    import dateutil.tz
+    return make_datetime_naive(datetime.datetime.fromtimestamp(ts).replace(tzinfo=dateutil.tz.tzlocal()))
+
+
 def parse_time(t):
     '''
     Try to make sense of the user provided time spec.
@@ -1067,11 +1087,12 @@ def parse_time(t):
 
     Also does time zone elimination by passing the datetime
     through a timestamp conversion if necessary
+
+    TODO: dateutil is very slow, avoid it if possible
     '''
     try:
-        import dateutil.parser
-        import dateutil.tz
-        dt = dateutil.parser.parse(t)
+        from dateutil import parser, tz
+        dt = parser.parse(t)
 
         if datetime_is_aware(dt):
             ts = datetime_to_timestamp(dt)
@@ -1080,9 +1101,9 @@ def parse_time(t):
             dt = datetime.datetime.fromtimestamp(ts)
         else:
             # convert to UTC from local time
-            dt = make_datetime_naive(dt.replace(tzinfo=dateutil.tz.tzlocal()))
+            dt = dt - tz.tzlocal().utcoffset(dt)
     except ValueError, msg:
-        common_err("%s: %s" % (t, msg))
+        common_err("parse_time %s: %s" % (t, msg))
         return None
     except ImportError, msg:
         try:
@@ -1094,6 +1115,35 @@ def parse_time(t):
     return dt
 
 
+def parse_to_timestamp(t):
+    '''
+    Read a string and convert it into a UNIX timestamp.
+    Added as an optimization of parse_time to avoid
+    extra conversion steps when result would be converted
+    into a timestamp anyway
+    '''
+    try:
+        from dateutil import parser, tz
+        dt = parser.parse(t)
+
+        if datetime_is_aware(dt):
+            return datetime_to_timestamp(dt)
+        else:
+            # convert to UTC from local time
+            return total_seconds(dt - tz.tzlocal().utcoffset(dt) - datetime.datetime(1970, 1, 1))
+    except ValueError, msg:
+        common_err("parse_time %s: %s" % (t, msg))
+        return None
+    except ImportError, msg:
+        try:
+            tm = time.strptime(t)
+            dt = datetime.datetime(*tm[0:7])
+            return datetime_to_timestamp(dt)
+        except ValueError, msg:
+            common_err("no dateutil, please provide times as printed by date(1)")
+            return None
+
+
 def save_graphviz_file(ini_f, attr_d):
     '''
     Save graphviz settings to an ini file, if it does not exist.
@@ -1337,6 +1387,25 @@ def resolve_hostnames(hostnames):
     return True, None
 
 
+def list_corosync_node_names():
+    '''
+    Returns list of nodes configured
+    in corosync.conf
+    '''
+    try:
+        cfg = os.getenv('COROSYNC_MAIN_CONFIG_FILE', '/etc/corosync/corosync.conf')
+        lines = open(cfg).read().split('\n')
+        name_re = re.compile(r'\s*name:\s+(.*)')
+        names = []
+        for line in lines:
+            name = name_re.match(line)
+            if name:
+                names.append(name.group(1))
+        return names
+    except Exception:
+        return []
+
+
 def list_corosync_nodes():
     '''
     Returns list of nodes configured
