@@ -3,7 +3,7 @@
 
 
 from crmsh import utils
-from crmsh import history
+from crmsh import logtime
 from nose.tools import eq_
 import time
 import datetime
@@ -14,4 +14,11 @@ def test_time_convert1():
     loctz = dateutil.tz.tzlocal()
     tm = time.localtime(utils.datetime_to_timestamp(utils.make_datetime_naive(datetime.datetime(2015, 6, 1, 10, 0, 0).replace(tzinfo=loctz))))
     dt = utils.parse_time('Jun 01, 2015 10:00:00')
-    eq_(history.human_date(dt), time.strftime('%Y-%m-%d %H:%M:%S', tm))
+    eq_(logtime.human_date(dt), time.strftime('%Y-%m-%d %H:%M:%S', tm))
+
+
+def test_time_convert2():
+    loctz = dateutil.tz.tzlocal()
+    tm = time.localtime(utils.datetime_to_timestamp(utils.make_datetime_naive(datetime.datetime(2015, 6, 1, 10, 0, 0).replace(tzinfo=loctz))))
+    ts = time.localtime(utils.parse_to_timestamp('Jun 01, 2015 10:00:00'))
+    eq_(time.strftime('%Y-%m-%d %H:%M:%S', ts), time.strftime('%Y-%m-%d %H:%M:%S', tm))
